package com.yanzhu.jh.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.service.ISurProjectService;

/**
 * 项目管理Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2023-07-29
 */
@Service
public class SurProjectServiceImpl implements ISurProjectService 
{
    @Autowired
    private SurProjectMapper surProjectMapper;

    /**
     * 查询项目管理
     * 
     * @param id 项目管理主键
     * @return 项目管理
     */
    @Override
    public SurProject selectSurProjectById(Long id)
    {
        return surProjectMapper.selectSurProjectById(id);
    }

    /**
     * 查询项目管理列表
     * 
     * @param surProject 项目管理
     * @return 项目管理
     */
    @Override
    public List<SurProject> selectSurProjectList(SurProject surProject)
    {
        return surProjectMapper.selectSurProjectList(surProject);
    }

    /**
     * 新增项目管理
     * 
     * @param surProject 项目管理
     * @return 结果
     */
    @Override
    public int insertSurProject(SurProject surProject)
    {
        surProject.setCreateTime(DateUtils.getNowDate());
        surProject.setIsDel(0l);
        return surProjectMapper.insertSurProject(surProject);
    }

    /**
     * 修改项目管理
     * 
     * @param surProject 项目管理
     * @return 结果
     */
    @Override
    public int updateSurProject(SurProject surProject)
    {
        surProject.setUpdateTime(DateUtils.getNowDate());
        return surProjectMapper.updateSurProject(surProject);
    }

    /**
     * 批量删除项目管理
     * 
     * @param ids 需要删除的项目管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectByIds(Long[] ids)
    {
        return surProjectMapper.deleteSurProjectByIds(ids);
    }

    /**
     * 删除项目管理信息
     * 
     * @param id 项目管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectById(Long id)
    {
        return surProjectMapper.deleteSurProjectById(id);
    }

    @Override
    public List<SurProject> selectProgressProjects(long deptId) {
        return surProjectMapper.selectProgressProjects(deptId);
    }

    @Override
    public List<SurProject> groupByProjectCategory(long deptId) {
        return surProjectMapper.groupByProjectCategory(deptId);
    }

    @Override
    public List<SurProject> groupByCategory(SurProject surProject) {
        return surProjectMapper.groupByCategory(surProject);
    }

    @Override
    public List<SurProject> groupByLevel(SurProject surProject) {
        return surProjectMapper.groupByLevel(surProject);
    }
}
